@@ -7,7 +7,7 @@ RDF::Trine::Parser::RDFXML - RDF/XML Parser.
 
 =head1 VERSION
 
-This document describes RDF::Trine::Parser::RDFXML version 0.107
+This document describes RDF::Trine::Parser::RDFXML version 0.108
 
 =head1 SYNOPSIS
 
@@ -45,7 +45,7 @@ use RDF::Trine::Parser::Error qw(:try);
 our ($VERSION, $debug);
 BEGIN {
 	$debug		= 0;
-	$VERSION	= 0.107;
+	$VERSION	= 0.108;
 	foreach my $t ('rdfxml', 'application/rdf+xml') {
 		$RDF::Trine::Parser::types{ $t }	= __PACKAGE__;
 	}
@@ -111,12 +111,11 @@ sub parse {
 		$self->{saxhandler}->set_handler( $handler );
 	}
 	
-	unless (ref($string)) {
-		my $data	= $string;
-		open( my $fh, '<', \$data );
-		$string	= $fh;
+	if (ref($string)) {
+		$self->{parser}->parse_file( $string );
+	} else {
+		$self->{parser}->parse_string( $string );
 	}
-	$self->{parser}->parse_file( $string );
 	my $nodes	= $self->{saxhandler}{nodes};
 	if ($nodes and scalar(@$nodes)) {
 		warn Dumper($nodes);
